@@ -15,8 +15,6 @@ import matplotlib.transforms as mtransforms
 
 from matplotlib.axes import SubplotBase
 
-import new
-
 import axes_size as Size
 
 
@@ -153,6 +151,8 @@ class Divider(object):
         :param horizontal: list of sizes
                     (:mod:`~mpl_toolkits.axes_grid.axes_size`)
                     for horizontal division
+
+        .
         """
         self._horizontal = h
 
@@ -166,6 +166,8 @@ class Divider(object):
         :param horizontal: list of sizes
                     (:mod:`~mpl_toolkits.axes_grid.axes_size`)
                     for horizontal division
+
+        .
         """
         self._vertical = v
 
@@ -276,7 +278,7 @@ class Divider(object):
             raise ValueError("the position must be one of left, right, bottom, or top")
 
 
-    def add_auto_adjustable_area(self, 
+    def add_auto_adjustable_area(self,
                                  use_axes, pad=0.1,
                                  adjust_dirs=["left", "right", "bottom", "top"],
                                  ):
@@ -339,7 +341,6 @@ class AxesLocator(object):
             return None
 
 
-            
 from matplotlib.gridspec import SubplotSpec, GridSpec
 
 class SubplotDivider(Divider):
@@ -897,9 +898,10 @@ def locatable_axes_factory(axes_class):
 
     new_class = _locatableaxes_classes.get(axes_class)
     if new_class is None:
-        new_class = new.classobj("Locatable%s" % (axes_class.__name__),
-                                 (LocatableAxesBase, axes_class),
-                                 {'_axes_class': axes_class})
+        new_class = type("Locatable%s" % (axes_class.__name__),
+                         (LocatableAxesBase, axes_class),
+                         {'_axes_class': axes_class})
+
         _locatableaxes_classes[axes_class] = new_class
 
     return new_class
@@ -919,10 +921,10 @@ def make_axes_locatable(axes):
 
     return divider
 
-def make_axes_area_auto_adjustable(ax, 
+def make_axes_area_auto_adjustable(ax,
                                    use_axes=None, pad=0.1,
                                    adjust_dirs=["left", "right", "bottom", "top"]):
-    
+
     divider = make_axes_locatable(ax)
 
     if use_axes is None:
@@ -934,5 +936,3 @@ def make_axes_area_auto_adjustable(ax,
 #from matplotlib.axes import Axes
 from mpl_axes import Axes
 LocatableAxes = locatable_axes_factory(Axes)
-
-
