@@ -11,6 +11,8 @@ Module containing Axes3D, an object which can plot 3D objects on a
 """
 
 import warnings
+from operator import itemgetter
+
 import matplotlib.axes as maxes
 from matplotlib.axes import Axes, rcParams
 from matplotlib import cbook
@@ -19,6 +21,7 @@ from matplotlib.transforms import Bbox
 import matplotlib.collections as mcoll
 from matplotlib import docstring
 import matplotlib.scale as mscale
+from matplotlib.tri.triangulation import Triangulation
 import numpy as np
 from matplotlib.colors import Normalize, colorConverter, LightSource
 
@@ -35,6 +38,7 @@ class Axes3D(Axes):
     3D axes object.
     """
     name = '3d'
+    _shared_z_axes = cbook.Grouper()
 
     def __init__(self, fig, rect=None, *args, **kwargs):
         '''
@@ -51,18 +55,22 @@ class Axes3D(Axes):
           *azim*             Azimuthal viewing angle (default -60)
           *elev*             Elevation viewing angle (default 30)
           *zscale*           [%(scale)s]
+          *sharez*           Other axes to share z-limits with
           ================   =========================================
+
+        .. versionadded :: 1.2.1
+            *sharez*
+
         ''' % {'scale': ' | '.join([repr(x) for x in mscale.get_scale_names()])}
 
         if rect is None:
             rect = [0.0, 0.0, 1.0, 1.0]
         self._cids = []
 
-        # TODO: Support z-axis sharing
-
         self.initial_azim = kwargs.pop('azim', -60)
         self.initial_elev = kwargs.pop('elev', 30)
         zscale = kwargs.pop('zscale', None)
+        sharez = kwargs.pop('sharez', None)
 
         self.xy_viewLim = unit_bbox()
         self.zz_viewLim = unit_bbox()
@@ -73,6 +81,11 @@ class Axes3D(Axes):
         self.view_init(self.initial_elev, self.initial_azim)
         self._ready = 0
 
+        self._sharez = sharez
+        if sharez is not None:
+            self._shared_z_axes.join(self, sharez)
+            self._adjustable = 'datalim'
+
         Axes.__init__(self, fig, rect,
                       frameon=True,
                       *args, **kwargs)
@@ -84,7 +97,7 @@ class Axes3D(Axes):
 
         # func used to format z -- fall back on major formatters
         self.fmt_zdata = None
-        
+
         if zscale is not None :
             self.set_zscale(zscale)
 
@@ -111,6 +124,50 @@ class Axes3D(Axes):
     def set_axis_on(self):
         self._axis3don = True
 
+    def have_units(self):
+        """
+        Return *True* if units are set on the *x*, *y*, or *z* axes
+
+        """
+        return (self.xaxis.have_units() or self.yaxis.have_units() or
+                self.zaxis.have_units())
+
+    def convert_zunits(self, z):
+        """
+        For artists in an axes, if the zaxis has units support,
+        convert *z* using zaxis unit type
+
+        .. versionadded :: 1.2.1
+
+        """
+        return self.zaxis.convert_units(z)
+
+    def _process_unit_info(self, xdata=None, ydata=None, zdata=None,
+                           kwargs=None):
+        """
+        Look for unit *kwargs* and update the axis instances as necessary
+
+        """
+        Axes._process_unit_info(self, xdata=xdata, ydata=ydata, kwargs=kwargs)
+
+        if self.xaxis is None or self.yaxis is None or self.zaxis is None:
+            return
+
+        if zdata is not None:
+            # we only need to update if there is nothing set yet.
+            if not self.zaxis.have_units():
+                self.zaxis.update_units(xdata)
+
+        # process kwargs 2nd since these will override default units
+        if kwargs is not None:
+            zunits = kwargs.pop('zunits', self.zaxis.units)
+            if zunits != self.zaxis.units:
+                self.zaxis.set_units(zunits)
+                # If the units being set imply a different converter,
+                # we need to update.
+                if zdata is not None:
+                    self.zaxis.update_units(zdata)
+
     def set_top_view(self):
         # this happens to be the right view for the viewing coordinates
         # moved up and to the left slightly to fit labels and axes
@@ -119,6 +176,8 @@ class Axes3D(Axes):
         ydwl = (0.95/self.dist)
         ydw = (0.9/self.dist)
 
+        # This is purposely using the 2D Axes's set_xlim and set_ylim,
+        # because we are trying to place our viewing pane.
         Axes.set_xlim(self, -xdwl, xdw, auto=None)
         Axes.set_ylim(self, -ydwl, ydw, auto=None)
 
@@ -187,16 +246,14 @@ class Axes3D(Axes):
         # Calculate projection of collections and zorder them
         zlist = [(col.do_3d_projection(renderer), col) \
                  for col in self.collections]
-        zlist.sort()
-        zlist.reverse()
+        zlist.sort(key=itemgetter(0), reverse=True)
         for i, (z, col) in enumerate(zlist):
             col.zorder = i
 
         # Calculate projection of patches and zorder them
         zlist = [(patch.do_3d_projection(renderer), patch) \
                 for patch in self.patches]
-        zlist.sort()
-        zlist.reverse()
+        zlist.sort(key=itemgetter(0), reverse=True)
         for i, (z, patch) in enumerate(zlist):
             patch.zorder = i
 
@@ -251,7 +308,7 @@ class Axes3D(Axes):
             This function was added, but not tested. Please report any bugs.
         """
         Axes.set_autoscale_on(self, b)
-        self.set_autoscalez_on(self, b)
+        self.set_autoscalez_on(b)
 
     def set_autoscalez_on(self, b) :
         """
@@ -406,22 +463,17 @@ class Axes3D(Axes):
 
         .. versionchanged :: 1.1.0
             Function signature was changed to better match the 2D version.
-            *tight* is now explicitly a kwarg and placed first. However,
-            it currently does not do anything.
-        """
+            *tight* is now explicitly a kwarg and placed first.
+            
+        .. versionchanged :: 1.2.1
+            This is now fully functional.
 
-        self.set_top_view()
+        """
         if not self._ready:
             return
 
-        # TODO: This is nearly the equivalent code from the 2D
-        #       version, but it doesn't seem to work correctly.
-        #       Therefore, we are currently staying with the
-        #       same old behavior.
-        """
         # This method looks at the rectangular volume (see above)
         # of data and decides how to scale the view portal to fit it.
-
         if tight is None:
             # if image data only just use the datalim
             _tight = self._tight or (len(self.images)>0 and
@@ -430,13 +482,48 @@ class Axes3D(Axes):
         else:
             _tight = self._tight = bool(tight)
 
-        Axes.autoscale_view(self, tight=_tight, scalex=scalex, scaley=scaley)
+        if scalex and self._autoscaleXon:
+            xshared = self._shared_x_axes.get_siblings(self)
+            dl = [ax.dataLim for ax in xshared]
+            bb = mtransforms.BboxBase.union(dl)
+            x0, x1 = self.xy_dataLim.intervalx
+            xlocator = self.xaxis.get_major_locator()
+            try:
+                x0, x1 = xlocator.nonsingular(x0, x1)
+            except AttributeError:
+                x0, x1 = mtransforms.nonsingular(x0, x1, increasing=False,
+                                                         expander=0.05)
+            if self._xmargin > 0:
+                delta = (x1 - x0) * self._xmargin
+                x0 -= delta
+                x1 += delta
+            if not _tight:
+                x0, x1 = xlocator.view_limits(x0, x1)
+            self.set_xbound(x0, x1)
+
+        if scaley and self._autoscaleYon:
+            yshared = self._shared_y_axes.get_siblings(self)
+            dl = [ax.dataLim for ax in yshared]
+            bb = mtransforms.BboxBase.union(dl)
+            y0, y1 = self.xy_dataLim.intervaly
+            ylocator = self.yaxis.get_major_locator()
+            try:
+                y0, y1 = ylocator.nonsingular(y0, y1)
+            except AttributeError:
+                y0, y1 = mtransforms.nonsingular(y0, y1, increasing=False,
+                                                         expander=0.05)
+            if self._ymargin > 0:
+                delta = (y1 - y0) * self._ymargin
+                y0 -= delta
+                y1 += delta
+            if not _tight:
+                y0, y1 = ylocator.view_limits(y0, y1)
+            self.set_ybound(y0, y1)
 
         if scalez and self._autoscaleZon:
-            # TODO: mplot3d does not support the sharing of Z axis.
-            #zshared = self._shared_z_axes.get_siblings(self)
-            #dl = [ax.dataLim for ax in zshared]
-            #bb = mtransforms.BboxBase.union(dl)
+            zshared = self._shared_z_axes.get_siblings(self)
+            dl = [ax.dataLim for ax in zshared]
+            bb = mtransforms.BboxBase.union(dl)
             z0, z1 = self.zz_dataLim.intervalx
             zlocator = self.zaxis.get_major_locator()
             try:
@@ -451,16 +538,6 @@ class Axes3D(Axes):
             if not _tight:
                 z0, z1 = zlocator.view_limits(z0, z1)
             self.set_zbound(z0, z1)
-        """
-        # Previous version's code
-        if not self.get_autoscale_on():
-            return
-        if scalex:
-            self.set_xlim3d(self.xy_dataLim.intervalx)
-        if scaley:
-            self.set_ylim3d(self.xy_dataLim.intervaly)
-        if scalez:
-            self.set_zlim3d(self.zz_dataLim.intervalx)
 
     def get_w_lims(self):
         '''Get 3D world limits.'''
@@ -477,44 +554,167 @@ class Axes3D(Axes):
             xmax += 0.05
         return (xmin, xmax)
 
-    def set_xlim3d(self, *args, **kwargs):
-        '''
+    def set_xlim3d(self, left=None, right=None, emit=True, auto=False, **kw):
+        """
         Set 3D x limits.
 
         See :meth:`matplotlib.axes.Axes.set_xlim` for full documentation.
-        '''
-        # TODO: Add compatibility for 'left' and 'right'
-        # TODO: support 'emit' and 'auto'
-        lims = self._determine_lims(*args, **kwargs)
-        self.xy_viewLim.intervalx = lims
-        return lims
+
+        """
+        if 'xmin' in kw:
+            left = kw.pop('xmin')
+        if 'xmax' in kw:
+            right = kw.pop('xmax')
+        if kw:
+            raise ValueError("unrecognized kwargs: %s" % kw.keys())
+
+        if right is None and cbook.iterable(left):
+            left, right = left
+
+        self._process_unit_info(xdata=(left, right))
+        if left is not None:
+            left = self.convert_xunits(left)
+        if right is not None:
+            right = self.convert_xunits(right)
+
+        old_left, old_right = self.get_xlim()
+        if left is None:
+            left = old_left
+        if right is None:
+            right = old_right
+
+        if left == right:
+            warnings.warn(('Attempting to set identical left==right results\n'
+                     'in singular transformations; automatically expanding.\n'
+                     'left=%s, right=%s') % (left, right))
+        left, right = mtransforms.nonsingular(left, right, increasing=False)
+        left, right = self.xaxis.limit_range_for_scale(left, right)
+        self.xy_viewLim.intervalx = (left, right)
+
+        if auto is not None:
+            self._autoscaleXon = bool(auto)
+
+        if emit:
+            self.callbacks.process('xlim_changed', self)
+            # Call all of the other x-axes that are shared with this one
+            for other in self._shared_x_axes.get_siblings(self):
+                if other is not self:
+                    other.set_xlim(self.xy_viewLim.intervalx,
+                                            emit=False, auto=auto)
+                    if (other.figure != self.figure and
+                        other.figure.canvas is not None):
+                        other.figure.canvas.draw_idle()
+
+        return left, right
     set_xlim = set_xlim3d
 
 
-    def set_ylim3d(self, *args, **kwargs):
-        '''
+    def set_ylim3d(self, bottom=None, top=None, emit=True, auto=False, **kw):
+        """
         Set 3D y limits.
 
         See :meth:`matplotlib.axes.Axes.set_ylim` for full documentation.
-        '''
-        # TODO: Add compatibility for 'top' and 'bottom'
-        # TODO: support 'emit' and 'auto'
-        lims = self._determine_lims(*args, **kwargs)
-        self.xy_viewLim.intervaly = lims
-        return lims
+
+        """
+        if 'ymin' in kw:
+            bottom = kw.pop('ymin')
+        if 'ymax' in kw:
+            top = kw.pop('ymax')
+        if kw:
+            raise ValueError("unrecognized kwargs: %s" % kw.keys())
+
+        if top is None and cbook.iterable(bottom):
+            bottom, top = bottom
+
+        self._process_unit_info(ydata=(bottom, top))
+        if bottom is not None:
+            bottom = self.convert_yunits(bottom)
+        if top is not None:
+            top = self.convert_yunits(top)
+
+        old_bottom, old_top = self.get_ylim()
+        if bottom is None:
+            bottom = old_bottom
+        if top is None:
+            top = old_top
+
+        if top == bottom:
+            warnings.warn(('Attempting to set identical bottom==top results\n'
+                     'in singular transformations; automatically expanding.\n'
+                     'bottom=%s, top=%s') % (bottom, top))
+        bottom, top = mtransforms.nonsingular(bottom, top, increasing=False)
+        bottom, top = self.yaxis.limit_range_for_scale(bottom, top)
+        self.xy_viewLim.intervaly = (bottom, top)
+
+        if auto is not None:
+            self._autoscaleYon = bool(auto)
+
+        if emit:
+            self.callbacks.process('ylim_changed', self)
+            # Call all of the other y-axes that are shared with this one
+            for other in self._shared_y_axes.get_siblings(self):
+                if other is not self:
+                    other.set_ylim(self.xy_viewLim.intervaly,
+                                            emit=False, auto=auto)
+                    if (other.figure != self.figure and
+                        other.figure.canvas is not None):
+                        other.figure.canvas.draw_idle()
+
+        return bottom, top
     set_ylim = set_ylim3d
 
-    def set_zlim3d(self, *args, **kwargs):
-        '''
+    def set_zlim3d(self, bottom=None, top=None, emit=True, auto=False, **kw):
+        """
         Set 3D z limits.
 
-        See :meth:`matplotlib.axes.Axes.set_ylim` for full documentation.
-        '''
-        # TODO: Add compatibility for 'top' and 'bottom'
-        # TODO: support 'emit' and 'auto'
-        lims = self._determine_lims(*args, **kwargs)
-        self.zz_viewLim.intervalx = lims
-        return lims
+        See :meth:`matplotlib.axes.Axes.set_ylim` for full documentation
+        
+        """
+        if 'zmin' in kw:
+            bottom = kw.pop('zmin')
+        if 'zmax' in kw:
+            top = kw.pop('zmax')
+        if kw:
+            raise ValueError("unrecognized kwargs: %s" % kw.keys())
+
+        if top is None and cbook.iterable(bottom):
+            bottom, top = bottom
+
+        self._process_unit_info(zdata=(bottom, top))
+        if bottom is not None:
+            bottom = self.convert_zunits(bottom)
+        if top is not None:
+            top = self.convert_zunits(top)
+
+        old_bottom, old_top = self.get_zlim()
+        if bottom is None:
+            bottom = old_bottom
+        if top is None:
+            top = old_top
+
+        if top == bottom:
+            warnings.warn(('Attempting to set identical bottom==top results\n'
+                     'in singular transformations; automatically expanding.\n'
+                     'bottom=%s, top=%s') % (bottom, top))
+        bottom, top = mtransforms.nonsingular(bottom, top, increasing=False)
+        bottom, top = self.zaxis.limit_range_for_scale(bottom, top)
+        self.zz_viewLim.intervalx = (bottom, top)
+
+        if auto is not None:
+            self._autoscaleZon = bool(auto)
+
+        if emit:
+            self.callbacks.process('zlim_changed', self)
+            # Call all of the other y-axes that are shared with this one
+            for other in self._shared_z_axes.get_siblings(self):
+                if other is not self:
+                    other.set_zlim(self.zz_viewLim.intervalx,
+                                            emit=False, auto=auto)
+                    if (other.figure != self.figure and
+                        other.figure.canvas is not None):
+                        other.figure.canvas.draw_idle()
+
+        return bottom, top
     set_zlim = set_zlim3d
 
     def get_xlim3d(self):
@@ -608,10 +808,10 @@ class Axes3D(Axes):
         .. versionadded:: 1.1.0
         """
         return self.zaxis.set_ticks(*args, **kwargs)
-        
-    def get_zticks(self, *args, **kwargs):
+
+    def get_zticks(self, minor=False):
         """
-        Get the z-axis tick objects.
+        Return the z ticks as a list of locations
         See :meth:`matplotlib.axes.Axes.get_yticks` for more details.
 
         .. note::
@@ -619,7 +819,7 @@ class Axes3D(Axes):
 
         .. versionadded:: 1.1.0
         """
-        return self.zaxis.get_ticks(*args, **kwargs)
+        return self.zaxis.get_ticklocs(minor=minor)
 
     def get_zmajorticklabels(self) :
         """
@@ -633,7 +833,7 @@ class Axes3D(Axes):
     def get_zminorticklabels(self) :
         """
         Get the ztick labels as a list of Text instances
-        
+
         .. note::
             Minor ticks are not supported. This function was added
             only for completeness.
@@ -822,14 +1022,14 @@ class Axes3D(Axes):
         return False
 
     def cla(self):
-        """Clear axes and disable mouse button callbacks.
         """
-        self.disable_mouse_rotation()
+        Clear axes
+        """
+        # Disabling mouse interaction might have been needed a long
+        # time ago, but I can't find a reason for it now - BVR (2012-03)
+        #self.disable_mouse_rotation()
         self.zaxis.cla()
 
-        # TODO: Support sharez
-        self._sharez = None
-
         if self._sharez is not None:
             self.zaxis.major = self._sharez.zaxis.major
             self.zaxis.minor = self._sharez.zaxis.minor
@@ -1042,6 +1242,7 @@ class Axes3D(Axes):
         Set / unset 3D grid.
 
         .. note::
+
             Currently, this function does not behave the same as
             :meth:`matplotlib.axes.Axes.grid`, but it is intended to
             eventually support that behavior.
@@ -1188,7 +1389,7 @@ class Axes3D(Axes):
             This function was added, but not tested. Please report any bugs.
         """
         bottom, top = self.get_zlim()
-        self.set_zlim(top, bottom)
+        self.set_zlim(top, bottom, auto=None)
 
     def zaxis_inverted(self):
         '''
@@ -1224,7 +1425,7 @@ class Axes3D(Axes):
         .. versionadded :: 1.1.0
             This function was added, but not tested. Please report any bugs.
         """
-        if upper is None and iterable(lower):
+        if upper is None and cbook.iterable(lower):
             lower,upper = lower
 
         old_lower,old_upper = self.get_zbound()
@@ -1348,16 +1549,10 @@ class Axes3D(Axes):
         had_data = self.has_data()
 
         Z = np.atleast_2d(Z)
-        rows, cols = Z.shape
         # TODO: Support masked arrays
-        X = np.asarray(X)
-        Y = np.asarray(Y)
-        # Force X and Y to take the same shape.
-        # If they can not be fitted to that shape,
-        # then an exception is automatically thrown.
-        X.shape = (rows, cols)
-        Y.shape = (rows, cols)
-        
+        X, Y, Z = np.broadcast_arrays(X, Y, Z)
+        rows, cols = Z.shape
+
         rstride = kwargs.pop('rstride', 10)
         cstride = kwargs.pop('cstride', 10)
 
@@ -1393,7 +1588,7 @@ class Axes3D(Axes):
         #colset contains the data for coloring: either average z or the facecolor
         colset = []
         for rs in xrange(0, rows-1, rstride):
-            for cs in xrange(0, cols-1, cstride):  
+            for cs in xrange(0, cols-1, cstride):
                 ps = []
                 for a in (X, Y, Z) :
                     ztop = a[rs,cs:min(cols, cs+cstride+1)]
@@ -1522,14 +1717,8 @@ class Axes3D(Axes):
         had_data = self.has_data()
         Z = np.atleast_2d(Z)
         # FIXME: Support masked arrays
-        X = np.asarray(X)
-        Y = np.asarray(Y)
+        X, Y, Z = np.broadcast_arrays(X, Y, Z)
         rows, cols = Z.shape
-        # Force X and Y to take the same shape.
-        # If they can not be fitted to that shape,
-        # then an exception is automatically thrown.
-        X.shape = (rows, cols)
-        Y.shape = (rows, cols)
 
         # We want two sets of lines, one running along the "rows" of
         # Z and another set of lines running along the "columns" of Z.
@@ -1570,6 +1759,97 @@ class Axes3D(Axes):
 
         return linec
 
+    def plot_trisurf(self, X, Y, Z, *args, **kwargs):
+        """
+        ============= ================================================
+        Argument      Description
+        ============= ================================================
+        *X*, *Y*, *Z* Data values as 1D arrays
+        *color*       Color of the surface patches
+        *cmap*        A colormap for the surface patches.
+        *norm*        An instance of Normalize to map values to colors
+        *vmin*        Minimum value to map
+        *vmax*        Maximum value to map
+        *shade*       Whether to shade the facecolors
+        ============= ================================================
+
+        Other arguments are passed on to
+        :class:`~mpl_toolkits.mplot3d.art3d.Poly3DCollection`
+
+        .. versionadded:: 1.2.0
+            This plotting function was added for the v1.2.0 release.
+        """
+
+        had_data = self.has_data()
+
+        # TODO: Support custom face colours
+        color = np.array(colorConverter.to_rgba(kwargs.pop('color', 'b')))
+
+        cmap = kwargs.get('cmap', None)
+        norm = kwargs.pop('norm', None)
+        vmin = kwargs.pop('vmin', None)
+        vmax = kwargs.pop('vmax', None)
+        linewidth = kwargs.get('linewidth', None)
+        shade = kwargs.pop('shade', cmap is None)
+        lightsource = kwargs.pop('lightsource', None)
+
+        # TODO: Support masked triangulations
+        tri = Triangulation(X, Y)
+        x = tri.x
+        y = tri.y
+        triangles = tri.triangles
+
+        xt = x[triangles][...,np.newaxis]
+        yt = y[triangles][...,np.newaxis]
+        zt = np.array(Z)[triangles][...,np.newaxis]
+
+        verts = np.concatenate((xt, yt, zt), axis=2)
+
+        # Only need these vectors to shade if there is no cmap
+        if cmap is None and shade:
+            totpts = len(verts)
+            v1 = np.empty((totpts, 3))
+            v2 = np.empty((totpts, 3))
+            # This indexes the vertex points
+            which_pt = 0
+
+        colset = []
+        for i in xrange(len(verts)):
+            avgzsum = verts[i,0,2] + verts[i,1,2] + verts[i,2,2]
+            colset.append(avgzsum / 3.0)
+
+            # Only need vectors to shade if no cmap
+            if cmap is None and shade:
+                v1[which_pt] = np.array(verts[i,0]) - np.array(verts[i,1])
+                v2[which_pt] = np.array(verts[i,1]) - np.array(verts[i,2])
+                which_pt += 1
+
+        if cmap is None and shade:
+            normals = np.cross(v1, v2)
+        else:
+            normals = []
+
+        polyc = art3d.Poly3DCollection(verts, *args, **kwargs)
+
+        if cmap:
+            colset = np.array(colset)
+            polyc.set_array(colset)
+            if vmin is not None or vmax is not None:
+                polyc.set_clim(vmin, vmax)
+            if norm is not None:
+                polyc.set_norm(norm)
+        else:
+            if shade:
+                colset = self._shade_colors(color, normals)
+            else:
+                colset = color
+            polyc.set_facecolors(colset)
+
+        self.add_collection(polyc)
+        self.auto_scale_xyz(X, Y, Z, had_data)
+
+        return polyc
+
     def _3d_extend_contour(self, cset, stride=5):
         '''
         Extend a contour in 3D by creating
@@ -1853,9 +2133,13 @@ class Axes3D(Axes):
         ys = np.ma.ravel(ys)
         zs = np.ma.ravel(zs)
         if xs.size != ys.size:
-            raise ValueError("x and y must be the same size")
-        if xs.size != zs.size and zs.size == 1:
-            zs = np.array(zs[0] * xs.size)
+            raise ValueError("Arguments 'xs' and 'ys' must be of same size.")
+        if xs.size != zs.size:
+            if zs.size == 1:
+                zs = np.tile(zs[0], xs.size)
+            else:
+                raise ValueError(("Argument 'zs' must be of same size as 'xs' "
+                    "and 'ys' or of size 1."))
 
         s = np.ma.ravel(s)  # This doesn't have to match x, y in size.
 
@@ -1875,6 +2159,9 @@ class Axes3D(Axes):
             is_2d = False
         art3d.patch_collection_2d_to_3d(patches, zs=zs, zdir=zdir)
 
+        if self._zmargin < 0.05 and xs.size > 0:
+            self.set_zmargin(0.05)
+
         #FIXME: why is this necessary?
         if not is_2d:
             self.auto_scale_xyz(xs, ys, zs, had_data)
@@ -1916,7 +2203,7 @@ class Axes3D(Axes):
             vs = art3d.get_patch_verts(p)
             verts += vs.tolist()
             verts_zs += [z] * len(vs)
-            art3d.patch_2d_to_3d(p, zs, zdir)
+            art3d.patch_2d_to_3d(p, z, zdir)
             if 'alpha' in kwargs:
                 p.set_alpha(kwargs['alpha'])
 
@@ -2073,7 +2360,7 @@ def get_test_data(delta=0.05):
 
 
 ########################################################
-# Register Axes3D as a 'projection' object available 
+# Register Axes3D as a 'projection' object available
 # for use just like any other axes
 ########################################################
 import matplotlib.projections as proj
