@@ -46,40 +46,24 @@ WIN32 - VISUAL STUDIO 7.1 (2003)
 import os
 import re
 import subprocess
-from distutils import sysconfig
+from distutils import sysconfig, version
+from collections import defaultdict
 
-basedir = {
+# basedir is a dictionary keyed by sys.platform, and on most platforms it is
+# set to ['/usr/local', '/usr']. Giving this defaultdict a factory that
+# returns this default removes the need to update this code every time a new
+# version of freebsd comes out, for example, provided that the default basedir
+# remains sufficient on that platform
+basedir = defaultdict(lambda: ['/usr/local', '/usr'], {
+    # execptions to the ['/usr/local', '/usr'] defaults
     'win32'  : ['win32_static',],
-    'linux2-alpha' : ['/usr/local', '/usr'],
-    'linux2-hppa' : ['/usr/local', '/usr'],
-    'linux2-mips' : ['/usr/local', '/usr'],
-    'linux2-sparc' : ['/usr/local', '/usr'],
-    'linux2' : ['/usr/local', '/usr'],
-    'linux3' : ['/usr/local', '/usr'],
-    'linux'  : ['/usr/local', '/usr',],
-    'cygwin' : ['/usr/local', '/usr',],
-    '_darwin' : ['/sw/lib/freetype2', '/sw/lib/freetype219', '/usr/local',
-                '/usr', '/sw'],
-    # it appears builds with darwin are broken because of all the
-    # different flags the deps can be compile with, so I am pushing
-    # people to :
-    #   make -f make.osx fetch deps mpl_build mpl_install
-
-    'darwin' : [],
-
-    'freebsd4' : ['/usr/local', '/usr'],
-    'freebsd5' : ['/usr/local', '/usr'],
-    'freebsd6' : ['/usr/local', '/usr'],
+    'darwin' : ['/usr/local/', '/usr', '/usr/X11', '/opt/local'],
     'sunos5' : [os.getenv('MPLIB_BASE') or '/usr/local',],
-    'gnukfreebsd5' : ['/usr/local', '/usr'],
-    'gnukfreebsd6' : ['/usr/local', '/usr'],
-    'gnukfreebsd7' : ['/usr/local', '/usr'],
-    'gnukfreebsd8' : ['/usr/local', '/usr'],
     'gnu0' : ['/usr'],
     'aix5' : ['/usr/local'],
-}
+    })
 
-import sys, os, stat
+import sys
 
 from textwrap import fill
 from distutils.core import Extension
@@ -107,7 +91,6 @@ BUILT_TKAGG     = False
 BUILT_WINDOWING = False
 BUILT_CONTOUR   = False
 BUILT_DELAUNAY  = False
-BUILT_NXUTILS   = False
 BUILT_CONTOUR   = False
 BUILT_GDK       = False
 BUILT_PATH      = False
@@ -124,6 +107,7 @@ options = {'display_status': True,
            'verbose': False,
            'provide_pytz': 'auto',
            'provide_dateutil': 'auto',
+           'provide_six': 'auto',
            'build_agg': True,
            'build_gtk': 'auto',
            'build_gtkagg': 'auto',
@@ -138,6 +122,9 @@ defines = [
         ('PY_ARRAY_UNIQUE_SYMBOL', 'MPL_ARRAY_API'),
         ('PYCXX_ISO_CPP_LIB', '1')]
 
+if sys.version_info[0] >= 3:
+    defines.append(('PYCXX_PYTHON_2TO3', '1'))
+
 setup_cfg = os.environ.get('MPLSETUPCFG', 'setup.cfg')
 # Based on the contents of setup.cfg, determine the build options
 if os.path.exists(setup_cfg):
@@ -157,6 +144,10 @@ if os.path.exists(setup_cfg):
                                                          "dateutil")
     except: options['provide_dateutil'] = 'auto'
 
+    try: options['provide_six'] = config.getboolean("provide_packages",
+                                                    "six")
+    except: options['provide_six'] = 'auto'
+
     try: options['build_gtk'] = config.getboolean("gui_support", "gtk")
     except: options['build_gtk'] = 'auto'
 
@@ -182,6 +173,12 @@ else:
     basedirlist = basedir[sys.platform]
 print("basedirlist is: %s" % basedirlist)
 
+def make_extension(*args, **kwargs):
+    ext = Extension(*args, **kwargs)
+    for dir in basedirlist:
+        ext.include_dirs.append(os.path.join(dir, 'include'))
+    return ext
+
 if options['display_status']:
     def print_line(char='='):
         print(char * 76)
@@ -261,6 +258,20 @@ if sys.platform == 'win32' and win32_compiler == 'msvc':
 else:
     std_libs = ['stdc++', 'm']
 
+def set_pkgconfig_path():
+    pkgconfig_path = sysconfig.get_config_var('LIBDIR')
+    if pkgconfig_path is None:
+        return
+
+    pkgconfig_path = os.path.join(pkgconfig_path, 'pkgconfig')
+    if not os.path.isdir(pkgconfig_path):
+        return
+
+    try:
+        os.environ['PKG_CONFIG_PATH'] += ':' + pkgconfig_path
+    except KeyError:
+        os.environ['PKG_CONFIG_PATH'] = pkgconfig_path
+
 def has_pkgconfig():
     if has_pkgconfig.cache is not None:
         return has_pkgconfig.cache
@@ -270,6 +281,10 @@ def has_pkgconfig():
         #print 'environ',  os.environ['PKG_CONFIG_PATH']
         status, output = getstatusoutput("pkg-config --help")
         has_pkgconfig.cache = (status == 0)
+
+        # Set the PKG_CONFIG_PATH environment variable
+        if has_pkgconfig.cache:
+            set_pkgconfig_path()
     return has_pkgconfig.cache
 has_pkgconfig.cache = None
 
@@ -335,7 +350,7 @@ def find_include_file(include_dirs, filename):
     return False
 
 def check_for_freetype():
-    module = Extension('test', [])
+    module = make_extension('test', [])
     add_base_flags(module)
     if not get_pkgconfig(module, 'freetype2'):
         basedirs = module.include_dirs[:]  # copy the list to avoid inf loop!
@@ -351,7 +366,7 @@ def check_for_freetype():
     return True
 
 def check_for_libpng():
-    module = Extension("test", [])
+    module = make_extension("test", [])
     get_pkgconfig(module, 'libpng')
     add_base_flags(module)
 
@@ -417,6 +432,18 @@ def check_for_qt4():
                       pyqtconfig.Configuration().pyqt_version_str))
         return True
 
+def check_for_pyside():
+    try:
+        from PySide import __version__
+        from PySide import QtCore
+    except ImportError:
+        print_status("PySide", "no")
+        return False
+    else:
+        print_status("PySide", "Qt: %s, PySide: %s" %
+                     (QtCore.__version__, __version__))
+        return True
+
 def check_for_cairo():
     try:
         import cairo
@@ -427,24 +454,14 @@ def check_for_cairo():
         print_status("Cairo", cairo.version)
         return True
 
-def check_for_datetime():
-    try:
-        import datetime
-    except ImportError:
-        print_status("datetime", "no")
-        return False
-    else:
-        print_status("datetime", "present, version unknown")
-        return True
-
-def check_provide_pytz(hasdatetime=True):
-    if hasdatetime and (options['provide_pytz'] is True):
+def check_provide_pytz():
+    if options['provide_pytz'] is True:
         print_status("pytz", "matplotlib will provide")
         return True
     try:
         import pytz
     except ImportError:
-        if hasdatetime and options['provide_pytz']:
+        if options['provide_pytz']:
             print_status("pytz", "matplotlib will provide")
             return True
         else:
@@ -458,14 +475,14 @@ def check_provide_pytz(hasdatetime=True):
             print_status("pytz", pytz.__version__)
             return False
 
-def check_provide_dateutil(hasdatetime=True):
-    if hasdatetime and (options['provide_dateutil'] is True):
+def check_provide_dateutil():
+    if options['provide_dateutil'] is True:
         print_status("dateutil", "matplotlib will provide")
         return True
     try:
         import dateutil
     except ImportError:
-        if hasdatetime and options['provide_dateutil']:
+        if options['provide_dateutil']:
             print_status("dateutil", "matplotlib will provide")
             return True
         else:
@@ -483,6 +500,36 @@ def check_provide_dateutil(hasdatetime=True):
             print_status("dateutil", "present, version unknown")
             return False
 
+def check_provide_six():
+    # We don't need six on Python 2.x
+    if sys.version_info[0] < 3:
+        return
+
+    if options['provide_six'] is True:
+        print_status("six", "matplotlib will provide")
+        return True
+    try:
+        import six
+    except ImportError:
+        if options['provide_six']:
+            print_status("six", "matplotlib will provide")
+            return True
+        else:
+            print_status("six", "no")
+            return False
+    else:
+        try:
+            if six.__version__.endswith('mpl'):
+                print_status("six", "matplotlib will provide")
+                return True
+            else:
+                print_status("six", six.__version__)
+                return False
+        except AttributeError:
+            print_status("six", "present, version unknown")
+            return False
+
+
 def check_for_dvipng():
     try:
         stdin, stdout = run_child_process('dvipng -version')
@@ -529,20 +576,22 @@ def check_for_pdftops():
         print_status("pdftops", "no")
         return False
 
-def check_for_numpy():
+def check_for_numpy(min_version):
     try:
         import numpy
     except ImportError:
         print_status("numpy", "no")
-        print_message("You must install numpy 1.1 or later to build matplotlib.")
+        print_message("You must install numpy %s or later to build matplotlib." %
+                      min_version)
+        return False
+
+    expected_version = version.LooseVersion(min_version)
+    found_version = version.LooseVersion(numpy.__version__)
+    if not found_version >= expected_version:
+        print_message(
+            'numpy %s or later is required; you have %s' %
+            (min_version, numpy.__version__))
         return False
-    nn = numpy.__version__.split('.')
-    if not (int(nn[0]) >= 1 and int(nn[1]) >= 1):
-        if not (int(nn[0]) >= 2):
-            print_message(
-               'numpy 1.1 or later is required; you have %s' %
-               numpy.__version__)
-            return False
     module = Extension('test', [])
     add_numpy_flags(module)
     add_base_flags(module)
@@ -623,7 +672,7 @@ def check_for_gtk():
             gotit = True
 
     if gotit:
-        module = Extension('test', [])
+        module = make_extension('test', [])
         add_pygtk_flags(module)
         if not find_include_file(module.include_dirs, os.path.join("gtk", "gtk.h")):
             explanation = (
@@ -728,7 +777,10 @@ def check_for_tk():
     gotit = False
     explanation = None
     try:
-        import Tkinter
+        if sys.version_info[0] < 3:
+            import Tkinter
+        else:
+            import tkinter as Tkinter
     except ImportError:
         explanation = 'TKAgg requires Tkinter'
     except RuntimeError:
@@ -740,18 +792,18 @@ def check_for_tk():
             gotit = True
 
     if gotit:
-        module = Extension('test', [])
+        module = make_extension('test', [])
         try:
             explanation = add_tk_flags(module)
-        except RuntimeError:
-            # This deals with the change in exception handling syntax in
-            # python 3. If we only need to support >= 2.6, we can just use the
-            # commented out lines below.
-            exc_type,exc,tb = sys.exc_info()
-            explanation = str(exc)
-            gotit = False
-#        except RuntimeError, e:
-#            explanation = str(e)
+        # except RuntimeError:
+        #     # This deals with the change in exception handling syntax in
+        #     # python 3. If we only need to support >= 2.6, we can just use the
+        #     # commented out lines below.
+        #     exc_type,exc,tb = sys.exc_info()
+        #     explanation = str(exc)
+        #     gotit = False
+        except RuntimeError as e:
+            explanation = str(e)
         else:
             if not find_include_file(module.include_dirs, "tk.h"):
                 message = 'Tkinter present, but header files are not found. ' + \
@@ -798,7 +850,10 @@ def query_tcltk():
         return TCL_TK_CACHE
 
     # By this point, we already know that Tkinter imports correctly
-    import Tkinter
+    if sys.version_info[0] < 3:
+        import Tkinter
+    else:
+        import tkinter as Tkinter
     tcl_lib_dir = ''
     tk_lib_dir = ''
     # First try to open a Tk window (requires a running X server)
@@ -833,7 +888,14 @@ def query_tcltk():
     return TCL_TK_CACHE
 
 def parse_tcl_config(tcl_lib_dir, tk_lib_dir):
-    import Tkinter
+    try:
+        if sys.version_info[0] < 3:
+            import Tkinter
+        else:
+            import tkinter as Tkinter
+    except ImportError:
+        return None
+
     tcl_poss = [tcl_lib_dir,
                 os.path.normpath(os.path.join(tcl_lib_dir, '..')),
                 "/usr/lib/tcl"+str(Tkinter.TclVersion),
@@ -857,7 +919,7 @@ def parse_tcl_config(tcl_lib_dir, tk_lib_dir):
             executable="/bin/sh",
             stdout=subprocess.PIPE)
         result = p.communicate()[0]
-        return result
+        return result.decode('ascii')
 
     tcl_lib_dir = get_var(tcl_config, 'TCL_LIB_SPEC').split()[0][2:].strip()
     tcl_inc_dir = get_var(tcl_config, 'TCL_INCLUDE_SPEC')[2:].strip()
@@ -923,7 +985,7 @@ def add_tk_flags(module):
     message = None
     if sys.platform == 'win32':
         major, minor1, minor2, s, tmp = sys.version_info
-        if major == 2 and minor1 in [6, 7]:
+        if (2, 6) <= (major, minor1) <= (3, 3):
             module.include_dirs.extend(['win32_static/include/tcl85'])
             module.libraries.extend(['tk85', 'tcl85'])
         elif major == 2 and minor1 in [3, 4, 5]:
@@ -1036,7 +1098,7 @@ def build_windowing(ext_modules, packages):
        windows better, .e.g.  maintaining focus on win32"""
     global BUILT_WINDOWING
     if BUILT_WINDOWING: return # only build it if you you haven't already
-    module = Extension('matplotlib._windowing',
+    module = make_extension('matplotlib._windowing',
                        ['src/_windowing.cpp'],
                        )
     add_windowing_flags(module)
@@ -1050,7 +1112,7 @@ def build_ft2font(ext_modules, packages):
     deps.extend(glob.glob('CXX/*.cxx'))
     deps.extend(glob.glob('CXX/*.c'))
 
-    module = Extension('matplotlib.ft2font', deps,
+    module = make_extension('matplotlib.ft2font', deps,
                        define_macros=defines)
     add_ft2font_flags(module)
     ext_modules.append(module)
@@ -1064,7 +1126,7 @@ def build_ttconv(ext_modules, packages):
             'ttconv/pprdrv_tt2.cpp',
             'ttconv/ttutil.cpp']
 
-    module = Extension('matplotlib.ttconv', deps,
+    module = make_extension('matplotlib.ttconv', deps,
                        define_macros=defines)
     add_base_flags(module)
     ext_modules.append(module)
@@ -1077,7 +1139,7 @@ def build_gtkagg(ext_modules, packages):
     deps.extend(glob.glob('CXX/*.cxx'))
     deps.extend(glob.glob('CXX/*.c'))
 
-    module = Extension('matplotlib.backends._gtkagg',
+    module = make_extension('matplotlib.backends._gtkagg',
                        deps,
                        define_macros=defines
                        )
@@ -1100,7 +1162,7 @@ def build_tkagg(ext_modules, packages):
     deps.extend(glob.glob('CXX/*.cxx'))
     deps.extend(glob.glob('CXX/*.c'))
 
-    module = Extension('matplotlib.backends._tkagg',
+    module = make_extension('matplotlib.backends._tkagg',
                        deps,
                        define_macros=defines
                        )
@@ -1123,7 +1185,7 @@ def build_macosx(ext_modules, packages):
             'CXX/IndirectPythonInterface.cxx',
             'src/agg_py_transforms.cpp',
             'src/path_cleanup.cpp']
-    module = Extension('matplotlib.backends._macosx',
+    module = make_extension('matplotlib.backends._macosx',
                        deps,
                        extra_link_args = ['-framework','Cocoa'],
                        define_macros=defines
@@ -1141,7 +1203,7 @@ def build_png(ext_modules, packages):
     deps.extend(glob.glob('CXX/*.cxx'))
     deps.extend(glob.glob('CXX/*.c'))
 
-    module = Extension(
+    module = make_extension(
         'matplotlib._png',
         deps,
         include_dirs=numpy_inc_dirs,
@@ -1173,7 +1235,7 @@ def build_agg(ext_modules, packages):
     deps.extend(glob.glob('CXX/*.c'))
     temp_copy('src/_backend_agg.cpp', 'src/backend_agg.cpp')
     deps.append('src/backend_agg.cpp')
-    module = Extension(
+    module = make_extension(
         'matplotlib.backends._backend_agg',
         deps,
         include_dirs=numpy_inc_dirs,
@@ -1207,7 +1269,7 @@ def build_path(ext_modules, packages):
     deps.extend(['src/agg_py_transforms.cpp',
                  'src/path_cleanup.cpp',
                  'src/path.cpp'])
-    module = Extension(
+    module = make_extension(
         'matplotlib._path',
         deps,
         include_dirs=numpy_inc_dirs,
@@ -1236,7 +1298,7 @@ def build_image(ext_modules, packages):
     deps.extend(glob.glob('CXX/*.cxx'))
     deps.extend(glob.glob('CXX/*.c'))
 
-    module = Extension(
+    module = make_extension(
         'matplotlib._image',
         deps,
         include_dirs=numpy_inc_dirs,
@@ -1259,7 +1321,7 @@ def build_delaunay(ext_modules, packages):
     sourcefiles=["_delaunay.cpp", "VoronoiDiagramGenerator.cpp",
                  "delaunay_utils.cpp", "natneighbors.cpp"]
     sourcefiles = [os.path.join('lib/matplotlib/delaunay',s) for s in sourcefiles]
-    delaunay = Extension('matplotlib._delaunay',sourcefiles,
+    delaunay = make_extension('matplotlib._delaunay',sourcefiles,
                          include_dirs=numpy_inc_dirs,
                          define_macros=defines
                          )
@@ -1274,7 +1336,7 @@ def build_contour(ext_modules, packages):
     global BUILT_CONTOUR
     if BUILT_CONTOUR: return # only build it if you you haven't already
 
-    module = Extension(
+    module = make_extension(
         'matplotlib._cntr',
         [ 'src/cntr.c'],
         include_dirs=numpy_inc_dirs,
@@ -1287,28 +1349,12 @@ def build_contour(ext_modules, packages):
     BUILT_CONTOUR = True
 
 
-def build_nxutils(ext_modules, packages):
-    global BUILT_NXUTILS
-    if BUILT_NXUTILS: return # only build it if you you haven't already
-    module = Extension(
-        'matplotlib.nxutils',
-        [ 'src/nxutils.c'],
-        include_dirs=numpy_inc_dirs,
-        define_macros=defines
-        )
-    add_numpy_flags(module)
-    add_base_flags(module)
-    ext_modules.append(module)
-
-    BUILT_NXUTILS = True
-
-
 def build_gdk(ext_modules, packages):
     global BUILT_GDK
     if BUILT_GDK: return # only build it if you you haven't already
 
     temp_copy('src/_backend_gdk.c', 'src/backend_gdk.c')
-    module = Extension(
+    module = make_extension(
         'matplotlib.backends._backend_gdk',
         ['src/backend_gdk.c'],
         libraries = [],
@@ -1332,7 +1378,7 @@ def build_tri(ext_modules, packages):
     deps.extend(glob.glob('CXX/*.cxx'))
     deps.extend(glob.glob('CXX/*.c'))
 
-    module = Extension('matplotlib._tri', deps,
+    module = make_extension('matplotlib._tri', deps,
                        define_macros=defines)
     add_numpy_flags(module)
     add_base_flags(module)
