@@ -62,6 +62,7 @@ typedef agg::rasterizer_scanline_aa<agg::rasterizer_sl_clip_dbl> rasterizer;
 typedef agg::scanline_p8 scanline_p8;
 typedef agg::scanline_bin scanline_bin;
 typedef agg::amask_no_clip_gray8 alpha_mask_type;
+typedef agg::scanline_u8_am<alpha_mask_type> scanline_am;
 
 typedef agg::renderer_base<agg::pixfmt_gray8> renderer_base_alpha_mask_type;
 typedef agg::renderer_scanline_aa_solid<renderer_base_alpha_mask_type> renderer_alpha_mask_type;
@@ -195,6 +196,10 @@ public:
     Py::Object restore_region(const Py::Tuple & args);
     Py::Object restore_region2(const Py::Tuple & args);
 
+    #if PY3K
+    virtual int buffer_get( Py_buffer *, int flags );
+    #endif
+
     virtual ~RendererAgg();
 
     static const size_t PIXELS_PER_INCH;
@@ -211,7 +216,7 @@ public:
     agg::pixfmt_gray8 pixfmtAlphaMask;
     renderer_base_alpha_mask_type rendererBaseAlphaMask;
     renderer_alpha_mask_type rendererAlphaMask;
-    agg::scanline_p8 scanlineAlphaMask;
+    scanline_am scanlineAlphaMask;
 
     scanline_p8 slineP8;
     scanline_bin slineBin;
@@ -260,7 +265,8 @@ protected:
      const Py::Object&              edgecolors_obj,
      const Py::SeqBase<Py::Float>&  linewidths,
      const Py::SeqBase<Py::Object>& linestyles_obj,
-     const Py::SeqBase<Py::Int>&    antialiaseds);
+     const Py::SeqBase<Py::Int>&    antialiaseds,
+     const bool                     data_offsets);
 
     void
     _draw_gouraud_triangle(
@@ -296,4 +302,3 @@ private:
 
 
 #endif
-
