@@ -34,6 +34,7 @@
 
 
 typedef agg::pixfmt_rgba32 pixfmt;
+typedef agg::pixfmt_rgba32_pre pixfmt_pre;
 typedef agg::renderer_base<pixfmt> renderer_base;
 typedef agg::span_interpolator_linear<> interpolator_type;
 typedef agg::rasterizer_scanline_aa<agg::rasterizer_sl_clip_dbl> rasterizer;
@@ -200,8 +201,13 @@ Image::as_rgba_str(const Py::Tuple& args, const Py::Dict& kwargs)
 
     std::pair<agg::int8u*, bool> bufpair = _get_output_buffer();
 
+    #if PY3K
+    Py::Object ret =  Py::asObject(Py_BuildValue("lly#", rowsOut, colsOut,
+                                   bufpair.first, colsOut * rowsOut * 4));
+    #else
     Py::Object ret =  Py::asObject(Py_BuildValue("lls#", rowsOut, colsOut,
                                    bufpair.first, colsOut * rowsOut * 4));
+    #endif
 
     if (bufpair.second) delete [] bufpair.first;
     return ret;
@@ -221,9 +227,14 @@ Image::color_conv(const Py::Tuple& args)
 
     args.verify_length(1);
     int format = Py::Int(args[0]);
-
+    PyObject* py_buffer = NULL;
     int row_len = colsOut * 4;
-    PyObject* py_buffer = PyBuffer_New(row_len * rowsOut);
+#if PY3K
+    unsigned char* buf = (unsigned char *)malloc(row_len * rowsOut);
+    if (buf == NULL)
+        throw Py::MemoryError("Image::color_conv could not allocate memory");
+#else
+    py_buffer = PyBuffer_New(row_len * rowsOut);
     if (py_buffer == NULL)
         throw Py::MemoryError("Image::color_conv could not allocate memory");
 
@@ -231,7 +242,11 @@ Image::color_conv(const Py::Tuple& args)
     Py_ssize_t buffer_len;
     int ret = PyObject_AsWriteBuffer(py_buffer, &buf, &buffer_len);
     if (ret != 0)
+    {
+        Py_XDECREF(py_buffer);
         throw Py::MemoryError("Image::color_conv could not allocate memory");
+    }
+#endif
 
     agg::rendering_buffer rtmp;
     rtmp.attach(reinterpret_cast<unsigned char*>(buf), colsOut, rowsOut,
@@ -246,9 +261,17 @@ Image::color_conv(const Py::Tuple& args)
         agg::color_conv(&rtmp, rbufOut, agg::color_conv_rgba32_to_argb32());
         break;
     default:
+        Py_XDECREF(py_buffer);
         throw Py::ValueError("Image::color_conv unknown format");
     }
 
+#if PY3K
+    py_buffer = PyByteArray_FromStringAndSize((char *)buf, row_len * rowsOut);
+    if (py_buffer == NULL) {
+        free(buf);
+    }
+#endif
+
     PyObject* o = Py_BuildValue("llN", rowsOut, colsOut, py_buffer);
     return Py::asObject(o);
 }
@@ -408,9 +431,9 @@ Image::resize(const Py::Tuple& args, const Py::Dict& kwargs)
     ras.add_path(imageBox);
 
     typedef agg::wrap_mode_reflect reflect_type;
-    typedef agg::image_accessor_wrap<pixfmt, reflect_type, reflect_type> img_accessor_type;
+    typedef agg::image_accessor_wrap<pixfmt_pre, reflect_type, reflect_type> img_accessor_type;
 
-    pixfmt pixfmtin(*rbufIn);
+    pixfmt_pre pixfmtin(*rbufIn);
     img_accessor_type ia(pixfmtin);
     switch (interpolation)
     {
@@ -1039,8 +1062,7 @@ _image_module::fromarray2(const Py::Tuple& args)
         int rgba = A->dimensions[2] == 4;
         double r, g, b, alpha;
         const size_t N = imo->rowsIn * imo->colsIn;
-        size_t i = 0;
-        while (i < N)
+        for (size_t i = 0; i < N; ++i)
         {
             r = *(double *)(A->data++);
             g = *(double *)(A->data++);
@@ -1530,10 +1552,10 @@ _image_module::pcolor(const Py::Tuple& args)
     Py::Object xp = args[0];
     Py::Object yp = args[1];
     Py::Object dp = args[2];
-    unsigned int rows = Py::Int(args[3]);
-    unsigned int cols = Py::Int(args[4]);
+    unsigned int rows = (unsigned long)Py::Int(args[3]);
+    unsigned int cols = (unsigned long)Py::Int(args[4]);
     Py::Tuple bounds = args[5];
-    unsigned int interpolation = Py::Int(args[6]);
+    unsigned int interpolation = (unsigned long)Py::Int(args[6]);
 
     if (rows >= 32768 || cols >= 32768)
     {
@@ -1927,17 +1949,13 @@ _image_module::pcolor2(const Py::Tuple& args)
     return Py::asObject(imo);
 }
 
-
-
-#if defined(_MSC_VER)
-DL_EXPORT(void)
-#elif defined(__cplusplus)
-extern "C" void
+#if PY3K
+PyMODINIT_FUNC
+PyInit__image(void)
 #else
-void
-#endif
-
+PyMODINIT_FUNC
 init_image(void)
+#endif
 {
     _VERBOSE("init_image");
 
@@ -1966,8 +1984,8 @@ init_image(void)
 
     d["ASPECT_FREE"] = Py::Int(Image::ASPECT_FREE);
     d["ASPECT_PRESERVE"] = Py::Int(Image::ASPECT_PRESERVE);
+
+#if PY3K
+    return _image->module().ptr();
+#endif
 }
-
-
-
-
